################################################################
:mod:`.series <highcharts_core.options.series>`
################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  arcdiagram
  area
  bar
  base
  bellcurve
  boxplot
  bubble
  bullet
  data/index
  dependencywheel
  dumbbell
  funnel
  gauge
  heatmap
  histogram
  item
  labels
  networkgraph
  organization
  packedbubble
  pareto
  pictorial
  pie
  points
  polygon
  pyramid
  sankey
  scatter
  series_generator
  spline
  sunburst
  timeline
  treegraph
  treemap
  vector
  venn
  wordcloud

-------------------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.series <highcharts_core.options.series>`
    -
  * - :mod:`.options.series.arcdiagram <highcharts_core.options.series.arcdiagram>`
    - :class:`ArcDiagramSeries <highcharts_core.options.series.arcdiagram.ArcDiagramSeries>`
  * - :mod:`.options.series.area <highcharts_core.options.series.area>`
    - :class:`AreaSeries <highcharts_core.options.series.area.AreaSeries>`
      :class:`AreaRangeSeries <highcharts_core.options.series.area.AreaRangeSeries>`
      :class:`AreaSplineSeries <highcharts_core.options.series.area.AreaSplineSeries>`
      :class:`AreaSplineRangeSeries <highcharts_core.options.series.area.AreaSplineRangeSeries>`
      :class:`LineSeries <highcharts_core.options.series.area.LineSeries>`
      :class:`StreamGraphSeries <highcharts_core.options.series.area.StreamGraphSeries>`
  * - :mod:`.options.series.bar <highcharts_core.options.series.bar>`
    - :class:`BarSeries <highcharts_core.options.series.bar.BarSeries>`
      :class:`ColumnSeries <highcharts_core.options.series.bar.ColumnSeries>`
      :class:`ColumnPyramidSeries <highcharts_core.options.series.bar.ColumnPyramidSeries>`
      :class:`ColumnRangeSeries <highcharts_core.options.series.bar.ColumnRangeSeries>`
      :class:`CylinderSeries <highcharts_core.options.series.bar.CylinderSeries>`
      :class:`VariwideSeries <highcharts_core.options.series.bar.VariwideSeries>`
      :class:`WaterfallSeries <highcharts_core.options.series.bar.WaterfallSeries>`
      :class:`WindBarbSeries <highcharts_core.options.series.bar.WindBarbSeries>`
      :class:`XRangeSeries <highcharts_core.options.series.bar.XRangeSeries>`
      :class:`BaseBarSeries <highcharts_core.options.series.bar.BaseBarSeries>`
  * - :mod:`.options.series.base <highcharts_core.options.series.base>`
    - :class:`SeriesBase <highcharts_core.options.series.base.SeriesBase>`
  * - :mod:`.options.series.bellcurve <highcharts_core.options.series.bellcurve>`
    - :class:`BellCurveSeries <highcharts_core.options.series.bellcurve.BellCurveSeries>`
  * - :mod:`.options.series.boxplot <highcharts_core.options.series.boxplot>`
    - :class:`BoxPlotSeries <highcharts_core.options.series.boxplot.BoxPlotSeries>`
      :class:`ErrorBarSeries <highcharts_core.options.series.boxplot.ErrorBarSeries>`
  * - :mod:`.options.series.bubble <highcharts_core.options.series.bubble>`
    - :class:`BubbleSeries <highcharts_core.options.series.bubble.BubbleSeries>`
  * - :mod:`.options.series.bullet <highcharts_core.options.series.bullet>`
    - :class:`BulletSeries <highcharts_core.options.series.bullet.BulletSeries>`
  * - :mod:`.options.series.data <highcharts_core.options.series.data>`
    -
  * - :mod:`.options.series.data.accessibility <highcharts_core.options.series.data.accessibility>`
    - :class:`DataPointAccessibility <highcharts_core.options.series.data.accessibility.DataPointAccessibility>`
  * - :mod:`.options.series.data.arcdiagram <highcharts_core.options.series.data.arcdiagram>`
    - :class:`ArcDiagramData <highcharts_core.options.series.data.arcdiagram.ArcDiagramData>`
  * - :mod:`.options.series.data.bar <highcharts_core.options.series.data.bar>`
    - :class:`BarData <highcharts_core.options.series.data.bar.BarData>`
      :class:`WaterfallData <highcharts_core.options.series.data.bar.WaterfallData>`
      :class:`WindBarbData <highcharts_core.options.series.data.bar.WindBarbData>`
      :class:`XRangeData <highcharts_core.options.series.data.bar.XRangeData>`
  * - :mod:`.options.series.data.base <highcharts_core.options.series.data.base>`
    - :class:`DataBase <highcharts_core.options.series.data.base.DataBase>`
  * - :mod:`.options.series.data.boxplot <highcharts_core.options.series.data.boxplot>`
    - :class:`BoxPlotData <highcharts_core.options.series.data.boxplot.BoxPlotData>`
  * - :mod:`.options.series.data.bullet <highcharts_core.options.series.data.bullet>`
    - :class:`BulletData <highcharts_core.options.series.data.bullet.BulletData>`
  * - :mod:`.options.series.data.cartesian <highcharts_core.options.series.data.cartesian>`
    - :class:`CartesianData <highcharts_core.options.series.data.cartesian.CartesianData>`
      :class:`Cartesian3DData <highcharts_core.options.series.data.cartesian.Cartesian3DData>`
      :class:`CartesianValueData <highcharts_core.options.series.data.cartesian.CartesianValueData>`
  * - :mod:`.options.series.data.connections <highcharts_core.options.series.data.connections>`
    - :class:`ConnectionData <highcharts_core.options.series.data.connections.ConnectionData>`
      :class:`WeightedConnectionData <highcharts_core.options.series.data.connections.WeightedConnectionData>`
      :class:`OutgoingWeightedConnectionData <highcharts_core.options.series.data.connections.OutgoingWeightedConnectionData>`
      :class:`ConnectionBase <highcharts_core.options.series.data.connections.ConnectionBase>`
  * - :mod:`.options.series.data.pie <highcharts_core.options.series.data.pie>`
    - :class:`PieData <highcharts_core.options.series.data.pie.PieData>`
      :class:`VariablePieData <highcharts_core.options.series.data.pie.VariablePieData>`
  * - :mod:`.options.series.data.range <highcharts_core.options.series.data.range>`
    - :class:`RangeData <highcharts_core.options.series.data.range.RangeData>`
      :class:`ConnectedRangeData <highcharts_core.options.series.data.range.ConnectedRangeData>`
  * - :mod:`.options.series.data.single_point <highcharts_core.options.series.data.single_point>`
    - :class:`SinglePointData <highcharts_core.options.series.data.single_point.SinglePointData>`
      :class:`SingleValueData <highcharts_core.options.series.data.single_point.SingleValueData>`
      :class:`SingleXData <highcharts_core.options.series.data.single_point.SingleXData>`
      :class:`LabeledSingleXData <highcharts_core.options.series.data.single_point.LabeledSingleXData>`
      :class:`ConnectedSingleXData <highcharts_core.options.series.data.single_point.ConnectedSingleXData>`
      :class:`SinglePointBase <highcharts_core.options.series.data.single_point.SinglePointBase>`
  * - :mod:`.options.series.data.sunburst <highcharts_core.options.series.data.sunburst>`
    - :class:`SunburstData <highcharts_core.options.series.data.sunburst.SunburstData>`
  * - :mod:`.options.series.data.treegraph <highcharts_core.options.series.data.treegraph>`
    - :class:`TreegraphData <highcharts_core.options.series.data.treegraph.TreegraphData>`
  * - :mod:`.options.series.data.treemap <highcharts_core.options.series.data.treemap>`
    - :class:`TreemapData <highcharts_core.options.series.data.treemap.TreemapData>`
  * - :mod:`.options.series.data.vector <highcharts_core.options.series.data.vector>`
    - :class:`VectorData <highcharts_core.options.series.data.vector.VectorData>`
  * - :mod:`.options.series.data.venn <highcharts_core.options.series.data.venn>`
    - :class:`VennData <highcharts_core.options.series.data.venn.VennData>`
  * - :mod:`.options.series.data.wordcloud <highcharts_core.options.series.data.wordcloud>`
    - :class:`WordcloudData <highcharts_core.options.series.data.wordcloud.WordcloudData>`
  * - :mod:`.options.series.dependencywheel <highcharts_core.options.series.dependencywheel>`
    - :class:`DependencyWheelSeries <highcharts_core.options.series.dependencywheel.DependencyWheelSeries>`
  * - :mod:`.options.series.dumbbell <highcharts_core.options.series.dumbbell>`
    - :class:`DumbbellSeries <highcharts_core.options.series.dumbbell.DumbbellSeries>`
      :class:`LollipopSeries <highcharts_core.options.series.dumbbell.LollipopSeries>`
  * - :mod:`.options.series.funnel <highcharts_core.options.series.funnel>`
    - :class:`FunnelSeries <highcharts_core.options.series.funnel.FunnelSeries>`
      :class:`Funnel3DSeries <highcharts_core.options.series.funnel.Funnel3DSeries>`
  * - :mod:`.options.series.gauge <highcharts_core.options.series.gauge>`
    - :class:`GaugeSeries <highcharts_core.options.series.gauge.GaugeSeries>`
      :class:`SolidGaugeSeries <highcharts_core.options.series.gauge.SolidGaugeSeries>`
  * - :mod:`.options.series.heatmap <highcharts_core.options.series.heatmap>`
    - :class:`HeatmapSeries <highcharts_core.options.series.heatmap.HeatmapSeries>`
      :class:`TilemapSeries <highcharts_core.options.series.heatmap.TilemapSeries>`
  * - :mod:`.options.series.histogram <highcharts_core.options.series.histogram>`
    - :class:`HistogramSeries <highcharts_core.options.series.histogram.HistogramSeries>`
  * - :mod:`.options.series.item <highcharts_core.options.series.item>`
    - :class:`ItemSeries <highcharts_core.options.series.item.ItemSeries>`
  * - :mod:`.options.series.labels <highcharts_core.options.series.labels>`
    - :class:`SeriesLabel <highcharts_core.options.series.labels.SeriesLabel>`
      :class:`Box <highcharts_core.options.series.labels.Box>`
  * - :mod:`.options.series.networkgraph <highcharts_core.options.series.networkgraph>`
    - :class:`NetworkGraphSeries <highcharts_core.options.series.networkgraph.NetworkGraphSeries>`
  * - :mod:`.options.series.organization <highcharts_core.options.series.organization>`
    - :class:`OrganizationSeries <highcharts_core.options.series.organization.OrganizationSeries>`
  * - :mod:`.options.series.packedbubble <highcharts_core.options.series.packedbubble>`
    - :class:`PackedBubbleSeries <highcharts_core.options.series.packedbubble.PackedBubbleSeries>`
  * - :mod:`.options.series.pareto <highcharts_core.options.series.pareto>`
    - :class:`ParetoSeries <highcharts_core.options.series.pareto.ParetoSeries>`
  * - :mod:`.options.series.pictorial <highcharts_core.options.series.pictorial>`
    - :class:`PictorialSeries <highcharts_core.options.series.pictorial.PictorialSeries>`
      :class:`PictorialPaths <highcharts_core.options.series.pictorial.PictorialPaths>`
  * - :mod:`.options.series.pie <highcharts_core.options.series.pie>`
    - :class:`PieSeries <highcharts_core.options.series.pie.PieSeries>`
      :class:`VariablePieSeries <highcharts_core.options.series.pie.VariablePieSeries>`
  * - :mod:`.options.series.polygon <highcharts_core.options.series.polygon>`
    - :class:`PolygonSeries <highcharts_core.options.series.polygon.PolygonSeries>`
  * - :mod:`.options.series.pyramid <highcharts_core.options.series.pyramid>`
    - :class:`PyramidSeries <highcharts_core.options.series.pyramid.PyramidSeries>`
      :class:`Pyramid3DSeries <highcharts_core.options.series.pyramid.Pyramid3DSeries>`
  * - :mod:`.options.series.sankey <highcharts_core.options.series.sankey>`
    - :class:`SankeySeries <highcharts_core.options.series.sankey.SankeySeries>`
  * - :mod:`.options.series.scatter <highcharts_core.options.series.scatter>`
    - :class:`ScatterSeries <highcharts_core.options.series.scatter.ScatterSeries>`
      :class:`Scatter3DSeries <highcharts_core.options.series.scatter.Scatter3DSeries>`
  * - :mod:`.options.series.series_generator <highcharts_core.options.series.series_generator>`
    - :func:`create_series_obj() <highcharts_core.options.series.series_generator.create_series_obj>`
  * - :mod:`.options.series.spline <highcharts_core.options.series.spline>`
    - :class:`SplineSeries <highcharts_core.options.series.spline.SplineSeries>`
  * - :mod:`.options.series.sunburst <highcharts_core.options.series.sunburst>`
    - :class:`SunburstSeries <highcharts_core.options.series.sunburst.SunburstSeries>`
  * - :mod:`.options.series.timeline <highcharts_core.options.series.timeline>`
    - :class:`TimelineSeries <highcharts_core.options.series.timeline.TimelineSeries>`
  * - :mod:`.options.series.treegraph <highcharts_core.options.series.treegraph>`
    - :class:`TreegraphSeries <highcharts_core.options.series.treegraph.TreegraphSeries>`
  * - :mod:`.options.series.treemap <highcharts_core.options.series.treemap>`
    - :class:`TreemapSeries <highcharts_core.options.series.treemap.TreemapSeries>`
  * - :mod:`.options.series.vector <highcharts_core.options.series.vector>`
    - :class:`VectorSeries <highcharts_core.options.series.vector.VectorSeries>`
  * - :mod:`.options.series.venn <highcharts_core.options.series.venn>`
    - :class:`VennSeries <highcharts_core.options.series.venn.VennSeries>`
  * - :mod:`.options.series.wordcloud <highcharts_core.options.series.wordcloud>`
    - :class:`WordcloudSeries <highcharts_core.options.series.wordcloud.WordcloudSeries>`
